# frozen_string_literal: true

module AppleSignIn
  class ClientSecretGenerator
    include AutoInject[
      :apple_team_id,
      :apple_base_url,
      :apple_key_id,
      :apple_private_key
    ]

    def generate(identity_token)
      apple_client_id = extract_apple_client_id(identity_token)
      claims = create_claims(apple_client_id)
      jwt(claims)
    end

    private

    def jwt(claims)
      jwt = JSON::JWT.new(claims)
      jwt.kid = apple_key_id
      jws = jwt.sign(private_key, :ES256)
      jws.to_s
    end

    def create_claims(apple_client_id)
      {
        "iss" => apple_team_id,
        "iat" => Time.now.to_i,
        "exp" => 5.months.from_now.to_i,
        "aud" => apple_base_url,
        "sub" => apple_client_id
      }
    end

    def private_key
      OpenSSL::PKey::EC.new apple_private_key
    end

    def headers
      {
        "kid" => apple_key_id
      }
    end

    def extract_apple_client_id(identity_token)
      token_payload = JSON::JWT.decode(identity_token, :skip_verification)
      token_payload["aud"]
    end
  end
end