module AppleSignIn
  Container = Dry::Container.new

  APPLE_BASE_URL = "https://appleid.apple.com".freeze

  PROVIDER_NAMES = %w(apple).freeze

  # Constants
  Container.register(:provider_names, -> { PROVIDER_NAMES })
  Container.register(:apple_base_url, -> { APPLE_BASE_URL })
  Container.register(:apple_team_id, -> { ENV["APPLE_TEAM_ID"] })
  Container.register(:apple_key_id, -> { ENV["APPLE_KEY_ID"] })
  Container.register(:apple_private_key, -> { ENV("APPLE_PRIVATE_KEY") })
  Container.register(:apple_redirect_uri, -> { ENV["APPLE_REDIRECT_URI"] })
  Container.register(:apple_client_ids, -> { ENV["APPLE_CLIENT_IDS"].split(",") })
  
  # 3rd Party
  Container.register(:httparty, -> { HTTParty })

  # Actions
  Container.register(:apple_client_secret_generator, -> { AppleSignIn::ClientSecretGenerator.new })
  Container.register(:apple_api_caller, -> { AppleSignIn::ApiCaller.new })
  Container.register(:apple_identity_token_verifier, -> { AppleSignIn::IdentityTokenVerifier.new })
  Container.register(:apple_refresh_token_retriever, -> { AppleSignIn::RefreshTokenRetriever.new })
end
